.. _user:

#####################
User Reference Manual
#####################

:Release: |version|
:Date: |today|


This is the Py-ART user community’s reference guide, and it covers the most 
commonly used public functions, modules and classes. 
If more detail is required, the :ref:`developer` is an exhaustive listing of 
all private and public functions, modules and classes.

.. toctree::
    :maxdepth: 1

    core
    io
    aux_io
    correct
    retrieve
    graph
    map
    filters
    util
    bridge
    testing

Packages level functions:

.. currentmodule:: pyart
.. autosummary::
    :toctree: generated/

    load_config
    test
